[Pkg-javascript-commits] [less.js] 267/285: typo fixes

Jonas Smedegaard dr at jones.dk
Mon Oct 26 23:24:00 UTC 2015


This is an automated email from the git hooks/post-receive script.

js pushed a commit to annotated tag v2.0.0
in repository less.js.

commit 73f3fc4468808daa81e09b067047c5b150b83abb
Author: Veres Lajos <vlajos at gmail.com>
Date:   Sun Nov 2 23:18:29 2014 +0000

    typo fixes
---
 CHANGELOG.md                             |  4 ++--
 dist/less.js                             | 38 ++++++++++++++++----------------
 lib/less-browser/file-manager.js         |  6 ++---
 lib/less-node/file-manager.js            |  6 ++---
 lib/less-node/url-file-manager.js        |  4 ++--
 lib/less/environment/file-manager-api.js |  2 +-
 lib/less/import-manager.js               |  2 +-
 lib/less/parser/parser.js                | 22 +++++++++---------
 lib/less/tree/debug-info.js              |  4 ++--
 lib/less/tree/ruleset.js                 |  4 ++--
 test/css/mixins-guards.css               |  4 ++--
 test/less-test.js                        |  2 +-
 test/less/mixins-guards.less             |  4 ++--
 13 files changed, 51 insertions(+), 51 deletions(-)

diff --git a/CHANGELOG.md b/CHANGELOG.md
index 13b6712..f9e753e 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -196,7 +196,7 @@
  - support for guards on selectors (currently only if you have a single selector)
  - allow property merging through the +: syntax
  - Added min/max functions
- - Added length function and improved extract to work with comma seperated values
+ - Added length function and improved extract to work with comma separated values
  - when using import multiple, sub imports are imported multiple times into final output
  - fix bad spaces between namespace operators
  - do not compress comment if it begins with an exclamation mark
@@ -293,7 +293,7 @@
  - browser and server url re-writing is now aligned to not re-write (previous lessc behaviour)
  - url-rewriting can be made to re-write to be relative to the entry file using the relative-urls option (less.relativeUrls option)
  - rootpath option can be used to add a base path to every url
- - Support mixin argument seperator of ';' so you can pass comma seperated values. e.g. `.mixin(23px, 12px;);`
+ - Support mixin argument separator of ';' so you can pass comma separated values. e.g. `.mixin(23px, 12px;);`
  - Fix lots of problems with named arguments in corner cases, not behaving as expected
  - hsv, hsva, unit functions
  - fixed lots more bad error messages
diff --git a/lib/less-browser/file-manager.js b/lib/less-browser/file-manager.js
index 867f649..4fef205 100644
--- a/lib/less-browser/file-manager.js
+++ b/lib/less-browser/file-manager.js
@@ -84,7 +84,7 @@ FileManager.prototype.clearFileCache = function() {
 };
 
 FileManager.prototype.loadFile = function loadFile(filename, currentDirectory, options, environment) {
-    return new PromiseConstructor(function(fullfill, reject) {
+    return new PromiseConstructor(function(fulfill, reject) {
         if (currentDirectory && !this.isPathAbsolute(filename)) {
             filename = currentDirectory + filename;
         }
@@ -99,7 +99,7 @@ FileManager.prototype.loadFile = function loadFile(filename, currentDirectory, o
         if (options.useFileCache && fileCache[href]) {
             try {
                 var lessText = fileCache[href];
-                fullfill({ contents: lessText, filename: href, webInfo: { lastModified: new Date() }});
+                fulfill({ contents: lessText, filename: href, webInfo: { lastModified: new Date() }});
             } catch (e) {
                 reject({filename: href, message: "Error loading file " + href + " error was " + e.message});
             }
@@ -111,7 +111,7 @@ FileManager.prototype.loadFile = function loadFile(filename, currentDirectory, o
             fileCache[href] = data;
 
             // Use remote copy (re-parse)
-            fullfill({ contents: data, filename: href, webInfo: { lastModified: lastModified }});
+            fulfill({ contents: data, filename: href, webInfo: { lastModified: lastModified }});
         }, function doXHRError(status, url) {
             reject({ type: 'File', message: "'" + url + "' wasn't found (" + status + ")", href: href });
         });
diff --git a/lib/less-node/file-manager.js b/lib/less-node/file-manager.js
index a3c27fe..40ddc30 100644
--- a/lib/less-node/file-manager.js
+++ b/lib/less-node/file-manager.js
@@ -16,7 +16,7 @@ FileManager.prototype.supportsSync = function(filename, currentDirectory, option
 };
 
 FileManager.prototype.loadFile = function(filename, currentDirectory, options, environment) {
-    return new PromiseConstructor(function(fullfill, reject) {
+    return new PromiseConstructor(function(fulfill, reject) {
         var fullFilename,
             data;
 
@@ -43,7 +43,7 @@ FileManager.prototype.loadFile = function(filename, currentDirectory, options, e
             }
 
             data = fs.readFileSync(fullFilename, 'utf-8');
-            fullfill({ contents: data, filename: fullFilename});
+            fulfill({ contents: data, filename: fullFilename});
         } else {
             (function tryPathIndex(i) {
                 if (i < paths.length) {
@@ -58,7 +58,7 @@ FileManager.prototype.loadFile = function(filename, currentDirectory, options, e
                                 // do processing in the next tick to allow
                                 // file handling to dispose
                                 process.nextTick(function() {
-                                    fullfill({ contents: data, filename: fullFilename});
+                                    fulfill({ contents: data, filename: fullFilename});
                                 });
                             });
                         }
diff --git a/lib/less-node/url-file-manager.js b/lib/less-node/url-file-manager.js
index 9548c7e..5413615 100644
--- a/lib/less-node/url-file-manager.js
+++ b/lib/less-node/url-file-manager.js
@@ -15,7 +15,7 @@ UrlFileManager.prototype.supports = function(filename, currentDirectory, options
 };
 
 UrlFileManager.prototype.loadFile = function(filename, currentDirectory, options, environment) {
-    return new PromiseConstructor(function(fullfill, reject) {
+    return new PromiseConstructor(function(fulfill, reject) {
         if (request === undefined) {
             try { request = require('request'); }
             catch(e) { request = null; }
@@ -45,7 +45,7 @@ UrlFileManager.prototype.loadFile = function(filename, currentDirectory, options
             if (!body) {
                 logger.warn('Warning: Empty body (HTTP '+ res.statusCode + ') returned by "' + urlStr +'"');
             }
-            fullfill({ contents: body, filename: urlStr });
+            fulfill({ contents: body, filename: urlStr });
         });
     });
 };
diff --git a/lib/less/environment/file-manager-api.js b/lib/less/environment/file-manager-api.js
index d1a67b1..c4d043e 100644
--- a/lib/less/environment/file-manager-api.js
+++ b/lib/less/environment/file-manager-api.js
@@ -73,7 +73,7 @@ module.exports = {
     supports: function(filename, currentDirectory, options, environment) {
     },
     /**
-     * Loads a file asynchronously. Expects a promise that either rejects with an error or fullfills with an
+     * Loads a file asynchronously. Expects a promise that either rejects with an error or fulfills with an
      * object containing
      *  { filename: - full resolved path to file
      *    contents: - the contents of the file, as a string }
diff --git a/lib/less/import-manager.js b/lib/less/import-manager.js
index 9da2b86..6188b1d 100644
--- a/lib/less/import-manager.js
+++ b/lib/less/import-manager.js
@@ -16,7 +16,7 @@ module.exports = function(environment) {
         this.rootFilename = rootFileInfo.filename;
         this.paths = context.paths || [];  // Search paths, when importing
         this.contents = {};             // map - filename to contents of all the files
-        this.contentsIgnoredChars = {}; // map - filename to lines at the begining of each file to ignore
+        this.contentsIgnoredChars = {}; // map - filename to lines at the beginning of each file to ignore
         this.mime = context.mime;
         this.error = null;
         this.context = context;
diff --git a/lib/less/parser/parser.js b/lib/less/parser/parser.js
index c19ed92..adca2aa 100644
--- a/lib/less/parser/parser.js
+++ b/lib/less/parser/parser.js
@@ -618,7 +618,7 @@ var Parser = function Parser(context, imports, fileInfo) {
                     var entities = parsers.entities,
                         returner = { args:null, variadic: false },
                         expressions = [], argsSemiColon = [], argsComma = [],
-                        isSemiColonSeperated, expressionContainsNamed, name, nameLoop, value, arg;
+                        isSemiColonSeparated, expressionContainsNamed, name, nameLoop, value, arg;
 
                     parserInput.save();
 
@@ -629,10 +629,10 @@ var Parser = function Parser(context, imports, fileInfo) {
                             parserInput.commentStore.length = 0;
                             if (parserInput.currentChar() === '.' && parserInput.$re(/^\.{3}/)) {
                                 returner.variadic = true;
-                                if (parserInput.$char(";") && !isSemiColonSeperated) {
-                                    isSemiColonSeperated = true;
+                                if (parserInput.$char(";") && !isSemiColonSeparated) {
+                                    isSemiColonSeparated = true;
                                 }
-                                (isSemiColonSeperated ? argsSemiColon : argsComma)
+                                (isSemiColonSeparated ? argsSemiColon : argsComma)
                                     .push({ variadic: true });
                                 break;
                             }
@@ -662,7 +662,7 @@ var Parser = function Parser(context, imports, fileInfo) {
                         if (val && val instanceof tree.Variable) {
                             if (parserInput.$char(':')) {
                                 if (expressions.length > 0) {
-                                    if (isSemiColonSeperated) {
+                                    if (isSemiColonSeparated) {
                                         error("Cannot mix ; and , as delimiter types");
                                     }
                                     expressionContainsNamed = true;
@@ -685,10 +685,10 @@ var Parser = function Parser(context, imports, fileInfo) {
                                 nameLoop = (name = val.name);
                             } else if (!isCall && parserInput.$re(/^\.{3}/)) {
                                 returner.variadic = true;
-                                if (parserInput.$char(";") && !isSemiColonSeperated) {
-                                    isSemiColonSeperated = true;
+                                if (parserInput.$char(";") && !isSemiColonSeparated) {
+                                    isSemiColonSeparated = true;
                                 }
-                                (isSemiColonSeperated ? argsSemiColon : argsComma)
+                                (isSemiColonSeparated ? argsSemiColon : argsComma)
                                     .push({ name: arg.name, variadic: true });
                                 break;
                             } else if (!isCall) {
@@ -707,13 +707,13 @@ var Parser = function Parser(context, imports, fileInfo) {
                             continue;
                         }
 
-                        if (parserInput.$char(';') || isSemiColonSeperated) {
+                        if (parserInput.$char(';') || isSemiColonSeparated) {
 
                             if (expressionContainsNamed) {
                                 error("Cannot mix ; and , as delimiter types");
                             }
 
-                            isSemiColonSeperated = true;
+                            isSemiColonSeparated = true;
 
                             if (expressions.length > 1) {
                                 value = new(tree.Value)(expressions);
@@ -727,7 +727,7 @@ var Parser = function Parser(context, imports, fileInfo) {
                     }
 
                     parserInput.forget();
-                    returner.args = isSemiColonSeperated ? argsSemiColon : argsComma;
+                    returner.args = isSemiColonSeparated ? argsSemiColon : argsComma;
                     return returner;
                 },
                 //
diff --git a/lib/less/tree/debug-info.js b/lib/less/tree/debug-info.js
index 1603019..2b9292a 100644
--- a/lib/less/tree/debug-info.js
+++ b/lib/less/tree/debug-info.js
@@ -1,4 +1,4 @@
-var debugInfo = function(context, ctx, lineSeperator) {
+var debugInfo = function(context, ctx, lineSeparator) {
     var result="";
     if (context.dumpLineNumbers && !context.compress) {
         switch(context.dumpLineNumbers) {
@@ -9,7 +9,7 @@ var debugInfo = function(context, ctx, lineSeperator) {
                 result = debugInfo.asMediaQuery(ctx);
                 break;
             case 'all':
-                result = debugInfo.asComment(ctx) + (lineSeperator || "") + debugInfo.asMediaQuery(ctx);
+                result = debugInfo.asComment(ctx) + (lineSeparator || "") + debugInfo.asMediaQuery(ctx);
                 break;
         }
     }
diff --git a/lib/less/tree/ruleset.js b/lib/less/tree/ruleset.js
index 1dc3fda..35653bb 100644
--- a/lib/less/tree/ruleset.js
+++ b/lib/less/tree/ruleset.js
@@ -453,8 +453,8 @@ Ruleset.prototype.joinSelector = function (paths, context, selector) {
     }
 
     // The paths are [[Selector]]
-    // The first list is a list of comma seperated selectors
-    // The inner list is a list of inheritance seperated selectors
+    // The first list is a list of comma separated selectors
+    // The inner list is a list of inheritance separated selectors
     // e.g.
     // .a, .b {
     //   .c {
diff --git a/test/css/mixins-guards.css b/test/css/mixins-guards.css
index c3da674..2ab7cdd 100644
--- a/test/css/mixins-guards.css
+++ b/test/css/mixins-guards.css
@@ -79,7 +79,7 @@
   content: theme1 is not 'theme2';
   content: theme1 is theme1;
 }
-.variouse-types-comparision {
+.variouse-types-comparison {
   /**/
   content: true is not equal to false;
   content: false is not equal to true too;
@@ -121,7 +121,7 @@
   content: 1 2 is not equal to 3;
   content: 3 is not equal to 1 2 too;
 }
-.list-comparision {
+.list-comparison {
   /**/
   content: a b c is equal to a b c;
   content: a b c is equal to a b c too;
diff --git a/test/less-test.js b/test/less-test.js
index b4aa02a..0b0de4a 100644
--- a/test/less-test.js
+++ b/test/less-test.js
@@ -113,7 +113,7 @@ module.exports = function() {
                 options.sourceMapOutputFilename = name + ".css";
                 options.sourceMapBasepath = path.join(process.cwd(), "test/less");
                 options.sourceMapRootpath = "testweb/";
-                // TODO seperate options?
+                // TODO separate options?
                 options.sourceMap = options;
             }
 
diff --git a/test/less/mixins-guards.less b/test/less/mixins-guards.less
index 0426cf4..c077f95 100644
--- a/test/less/mixins-guards.less
+++ b/test/less/mixins-guards.less
@@ -140,7 +140,7 @@
 .generic(@a, @b) when not(@a = @b) {content: @a is not equal to @b}
 .generic(@a, @b) when not(@b = @a) {content: @b is not equal to @a too}
 
-.variouse-types-comparision {
+.variouse-types-comparison {
     .generic(true, false);
     .generic(1, true);
     .generic(2, 2px);
@@ -155,7 +155,7 @@
     .generic(1 2, 3);
 }
 
-.list-comparision {
+.list-comparison {
     .generic(a b c, a b c);
     .generic(a b c, a b d);
     .generic(a, b, c; a, b, c);

diff --git a/dist/less.js b/dist/less.js
index 31c2261..791c216 100644
--- a/dist/less.js
+++ b/dist/less.js
@@ -442,7 +442,7 @@ FileManager.prototype.clearFileCache = function() {
 };
 
 FileManager.prototype.loadFile = function loadFile(filename, currentDirectory, options, environment) {
-    return new PromiseConstructor(function(fullfill, reject) {
+    return new PromiseConstructor(function(fulfill, reject) {
         if (currentDirectory && !this.isPathAbsolute(filename)) {
             filename = currentDirectory + filename;
         }
@@ -457,7 +457,7 @@ FileManager.prototype.loadFile = function loadFile(filename, currentDirectory, o
         if (options.useFileCache && fileCache[href]) {
             try {
                 var lessText = fileCache[href];
-                fullfill({ contents: lessText, filename: href, webInfo: { lastModified: new Date() }});
+                fulfill({ contents: lessText, filename: href, webInfo: { lastModified: new Date() }});
             } catch (e) {
                 reject({filename: href, message: "Error loading file " + href + " error was " + e.message});
             }
@@ -469,7 +469,7 @@ FileManager.prototype.loadFile = function loadFile(filename, currentDirectory, o
             fileCache[href] = data;
 
             // Use remote copy (re-parse)
-            fullfill({ contents: data, filename: href, webInfo: { lastModified: lastModified }});
+            fulfill({ contents: data, filename: href, webInfo: { lastModified: lastModified }});
         }, function doXHRError(status, url) {
             reject({ type: 'File', message: "'" + url + "' wasn't found (" + status + ")", href: href });
         });
@@ -2107,7 +2107,7 @@ module.exports = function(environment) {
         this.rootFilename = rootFileInfo.filename;
         this.paths = context.paths || [];  // Search paths, when importing
         this.contents = {};             // map - filename to contents of all the files
-        this.contentsIgnoredChars = {}; // map - filename to lines at the begining of each file to ignore
+        this.contentsIgnoredChars = {}; // map - filename to lines at the beginning of each file to ignore
         this.mime = context.mime;
         this.error = null;
         this.context = context;
@@ -3349,7 +3349,7 @@ var Parser = function Parser(context, imports, fileInfo) {
                     var entities = parsers.entities,
                         returner = { args:null, variadic: false },
                         expressions = [], argsSemiColon = [], argsComma = [],
-                        isSemiColonSeperated, expressionContainsNamed, name, nameLoop, value, arg;
+                        isSemiColonSeparated, expressionContainsNamed, name, nameLoop, value, arg;
 
                     parserInput.save();
 
@@ -3360,10 +3360,10 @@ var Parser = function Parser(context, imports, fileInfo) {
                             parserInput.commentStore.length = 0;
                             if (parserInput.currentChar() === '.' && parserInput.$re(/^\.{3}/)) {
                                 returner.variadic = true;
-                                if (parserInput.$char(";") && !isSemiColonSeperated) {
-                                    isSemiColonSeperated = true;
+                                if (parserInput.$char(";") && !isSemiColonSeparated) {
+                                    isSemiColonSeparated = true;
                                 }
-                                (isSemiColonSeperated ? argsSemiColon : argsComma)
+                                (isSemiColonSeparated ? argsSemiColon : argsComma)
                                     .push({ variadic: true });
                                 break;
                             }
@@ -3393,7 +3393,7 @@ var Parser = function Parser(context, imports, fileInfo) {
                         if (val && val instanceof tree.Variable) {
                             if (parserInput.$char(':')) {
                                 if (expressions.length > 0) {
-                                    if (isSemiColonSeperated) {
+                                    if (isSemiColonSeparated) {
                                         error("Cannot mix ; and , as delimiter types");
                                     }
                                     expressionContainsNamed = true;
@@ -3416,10 +3416,10 @@ var Parser = function Parser(context, imports, fileInfo) {
                                 nameLoop = (name = val.name);
                             } else if (!isCall && parserInput.$re(/^\.{3}/)) {
                                 returner.variadic = true;
-                                if (parserInput.$char(";") && !isSemiColonSeperated) {
-                                    isSemiColonSeperated = true;
+                                if (parserInput.$char(";") && !isSemiColonSeparated) {
+                                    isSemiColonSeparated = true;
                                 }
-                                (isSemiColonSeperated ? argsSemiColon : argsComma)
+                                (isSemiColonSeparated ? argsSemiColon : argsComma)
                                     .push({ name: arg.name, variadic: true });
                                 break;
                             } else if (!isCall) {
@@ -3438,13 +3438,13 @@ var Parser = function Parser(context, imports, fileInfo) {
                             continue;
                         }
 
-                        if (parserInput.$char(';') || isSemiColonSeperated) {
+                        if (parserInput.$char(';') || isSemiColonSeparated) {
 
                             if (expressionContainsNamed) {
                                 error("Cannot mix ; and , as delimiter types");
                             }
 
-                            isSemiColonSeperated = true;
+                            isSemiColonSeparated = true;
 
                             if (expressions.length > 1) {
                                 value = new(tree.Value)(expressions);
@@ -3458,7 +3458,7 @@ var Parser = function Parser(context, imports, fileInfo) {
                     }
 
                     parserInput.forget();
-                    returner.args = isSemiColonSeperated ? argsSemiColon : argsComma;
+                    returner.args = isSemiColonSeparated ? argsSemiColon : argsComma;
                     return returner;
                 },
                 //
@@ -5224,7 +5224,7 @@ Condition.prototype.eval = function (context) {
 module.exports = Condition;
 
 },{"./node":66}],50:[function(require,module,exports){
-var debugInfo = function(context, ctx, lineSeperator) {
+var debugInfo = function(context, ctx, lineSeparator) {
     var result="";
     if (context.dumpLineNumbers && !context.compress) {
         switch(context.dumpLineNumbers) {
@@ -5235,7 +5235,7 @@ var debugInfo = function(context, ctx, lineSeperator) {
                 result = debugInfo.asMediaQuery(ctx);
                 break;
             case 'all':
-                result = debugInfo.asComment(ctx) + (lineSeperator || "") + debugInfo.asMediaQuery(ctx);
+                result = debugInfo.asComment(ctx) + (lineSeparator || "") + debugInfo.asMediaQuery(ctx);
                 break;
         }
     }
@@ -7290,8 +7290,8 @@ Ruleset.prototype.joinSelector = function (paths, context, selector) {
     }
 
     // The paths are [[Selector]]
     // The first list is a list of comma seperated selectors
     // The inner list is a list of inheritance seperated selectors
     // e.g.
     // .a, .b {
     //   .c {
@@ -7290,8 +7290,8 @@ Ruleset.prototype.joinSelector = function (paths, context, selector) {
 
     // The paths are [[Selector]]
-    // The first list is a list of comma seperated selectors
-    // The inner list is a list of inheritance seperated selectors
+    // The first list is a list of comma separated selectors
+    // The inner list is a list of inheritance separated selectors
     // e.g.
     // .a, .b {
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-javascript/less.js.git



More information about the Pkg-javascript-commits mailing list